/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Geolocation.
 *
 * The Initial Developer of the Original Code is Mozilla Corporation
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Doug Turner <dougt@meer.net>  (Original Author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

[scriptable, uuid(E28E614F-8F86-44FF-BCF5-5F18225834A0)]
interface nsIWifiAccessPoint : nsISupports
{
  
  /*
   * The mac address of the WiFi node.  The format of this string is:
   * XX-XX-XX-XX-XX-XX
   */

  readonly attribute ACString mac;

  /*
   * Public name of a wireless network.  The charset of this string is ASCII.
   * This string will be null if not available.
   *
   * Note that this is a conversion of the SSID which makes it "displayable".
   * for any comparisons, you want to use the Raw SSID.
   */

  readonly attribute AString ssid;

  /*
   * Public name of a wireless network.  These are the bytes that are read off
   * of the network, may contain nulls, and generally shouldn't be displayed to
   * the user.
   *
   */

  readonly attribute ACString rawSSID;

  /*
   * Current signal strength measured in dBm.
   */
  readonly attribute long signal;
};
